==> open-xchange-documents-backend_7.8.4.orig.tar.bz2: open-xchange-documents-backend-7.8.4/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/ods/dom/Drawings.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.filter.ods.dom;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import org.apache.xml.serializer.SerializationHandler;
import org.odftoolkit.odfdom.pkg.OdfPackage;
import org.xml.sax.SAXException;
import com.openexchange.office.filter.odf.DLList;
import com.openexchange.office.filter.odf.INodeAccessor;
import com.openexchange.office.filter.odf.Namespaces;
import com.openexchange.office.filter.odf.OdfOperationDoc;
import com.openexchange.office.filter.odf.SaxContextHandler;
import com.openexchange.office.filter.odf.draw.DrawFrame;
import com.openexchange.office.filter.odf.draw.DrawObject;
import com.openexchange.office.filter.odf.draw.DrawingType;
import com.openexchange.office.filter.ods.dom.chart.ChartContent;

public class Drawings implements INodeAccessor {

	// each drawing of a page
    private DLList<Drawing> indexedDrawings;
	// each drawing that is anchored to a cell (top left anchor position is hashed)
	private final HashMap<DrawingAnchor, List<Drawing>> anchoredDrawings;

	public Drawings() {
		indexedDrawings = new DLList<Drawing>();
		anchoredDrawings = new HashMap<DrawingAnchor, List<Drawing>>();
    }

	public void writeSheetDrawings(SerializationHandler output)
		throws SAXException {

	    int i = 0;

	    final Iterator<Drawing> drawingIter = indexedDrawings.iterator();
	    while(drawingIter.hasNext()) {
	        final Drawing drawing = drawingIter.next();
	        drawing.getAttributes().setIntValue(Namespaces.DRAW, "z-index", "draw:z-index", i++);

			// only writing drawings without anchor...
			if(drawing.getAnchor()==null) {
				SaxContextHandler.startElement(output, Namespaces.TABLE, "shapes", "table:shapes");
				drawing.writeObject(output);
				SaxContextHandler.endElement(output, Namespaces.TABLE, "shapes", "table:shapes");
			}
		}
	}

    @Override
    public DLList<Object> getContent() {
        return (DLList)indexedDrawings;
    }

	public int getCount() {
		return indexedDrawings.size();
	}

	public Drawing getDrawing(int index) {
		return indexedDrawings.get(index);
	}

	public void addDrawing(Drawing drawing) {
	    addDrawing(drawing, indexedDrawings.size());
    }

    public void addDrawing(Drawing drawing, int index) {
        indexedDrawings.add(index, drawing);

		final DrawingAnchor anchor = drawing.getAnchor();
		if(anchor!=null) {
			List<Drawing> anchoredDrawingsList = anchoredDrawings.get(anchor);
			if(anchoredDrawingsList==null) {
				anchoredDrawingsList = new ArrayList<Drawing>();
				anchoredDrawings.put(anchor, anchoredDrawingsList);
			}
			anchoredDrawingsList.add(drawing);
		}
	}

    public void moveDrawing(int from, int to) {
        Drawing drawing = indexedDrawings.remove(from);
        indexedDrawings.add(to, drawing);
    }

	public void setDrawingAnchor(DrawingAnchor newAnchor, Drawing drawing) {

		// first removing the old anchor if any
		if(drawing.getAnchor()!=null) {
			final List<Drawing> anchoredDrawingList = anchoredDrawings.get(drawing.getAnchor());
			anchoredDrawingList.remove(drawing);
			if(anchoredDrawingList.isEmpty()) {
				anchoredDrawings.remove(drawing.getAnchor());
			}
 		}
		// adding our new drawingAnchor
		drawing.setDrawingAnchor(newAnchor);
		if(newAnchor!=null) {
		    List<Drawing> anchoredDrawingsList = anchoredDrawings.get(newAnchor);
			if(anchoredDrawingsList==null) {
				anchoredDrawingsList = new ArrayList<Drawing>();
				anchoredDrawings.put(newAnchor, anchoredDrawingsList);
			}
			anchoredDrawingsList.add(drawing);
		}
	}

	public List<Drawing> getIndexedDrawings() {
	    return indexedDrawings;
	}

	public List<Drawing> getAnchoredDrawings(DrawingAnchor drawingAnchor) {
		return anchoredDrawings.get(drawingAnchor);
	}

    public void deleteDrawing(int index, OdfOperationDoc opsDoc) {
		final Drawing drawing = indexedDrawings.remove(index);
		if(drawing.getAnchor()!=null) {
			final List<Drawing> anchoredDrawingList = anchoredDrawings.get(drawing.getAnchor());
			anchoredDrawingList.remove(drawing);
			if(anchoredDrawingList.isEmpty()) {
				anchoredDrawings.remove(drawing.getAnchor());
			}
		}
		if(drawing.getType()==DrawingType.CHART) {
		    final ChartContent chart = ((DrawObject)((DrawFrame)drawing.getShape()).getDrawing()).getChart();
	        if (chart!=null) {
	            final OdfPackage pkg = opsDoc.getDocument().getPackage();
	            final String internalPath = chart.getDocument().getDocumentPath();
	            pkg.remove(internalPath + "content.xml");
	            pkg.remove(internalPath + "meta.xml");
	            pkg.remove(internalPath + "styles.xml");
	            pkg.removeDocument(internalPath);
	        }
		}
	}
}

==> open-xchange-documents-backend_7.10.1.orig.tar.bz2: open-xchange-documents-backend-7.10.1/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/ods/dom/Drawings.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.filter.ods.dom;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import org.apache.xml.serializer.SerializationHandler;
import org.odftoolkit.odfdom.pkg.OdfPackage;
import org.xml.sax.SAXException;
import com.openexchange.office.filter.odf.DLList;
import com.openexchange.office.filter.odf.DLNode;
import com.openexchange.office.filter.odf.INodeAccessor;
import com.openexchange.office.filter.odf.Namespaces;
import com.openexchange.office.filter.odf.OdfOperationDoc;
import com.openexchange.office.filter.odf.SaxContextHandler;
import com.openexchange.office.filter.odf.draw.DrawFrame;
import com.openexchange.office.filter.odf.draw.DrawObject;
import com.openexchange.office.filter.odf.draw.DrawingType;
import com.openexchange.office.filter.ods.dom.chart.ChartContent;

public class Drawings implements INodeAccessor {

	// each drawing of a page
    private DLList<Drawing> indexedDrawings;
	// each drawing that is anchored to a cell (top left anchor position is hashed)
	private final HashMap<DrawingAnchor, List<Drawing>> anchoredDrawings;

	public Drawings() {
		indexedDrawings = new DLList<Drawing>();
		anchoredDrawings = new HashMap<DrawingAnchor, List<Drawing>>();
    }

	public void writeSheetDrawings(SerializationHandler output)
		throws SAXException {

	    int i = 0;

	    final Iterator<Drawing> drawingIter = indexedDrawings.iterator();
	    while(drawingIter.hasNext()) {
	        final Drawing drawing = drawingIter.next();
	        drawing.getAttributes().setIntValue(Namespaces.DRAW, "z-index", "draw:z-index", i++);

			// only writing drawings without anchor...
			if(drawing.getAnchor()==null) {
				SaxContextHandler.startElement(output, Namespaces.TABLE, "shapes", "table:shapes");
				drawing.writeObject(output);
				SaxContextHandler.endElement(output, Namespaces.TABLE, "shapes", "table:shapes");
			}
		}
	}

    @Override
    public DLList<Object> getContent() {
        return (DLList)indexedDrawings;
    }

	public int getCount() {
		return indexedDrawings.size();
	}

	public Drawing getDrawing(int index) {
		return indexedDrawings.get(index);
	}

	public void addDrawing(Drawing drawing) {
	    addDrawingNode(new DLNode<Object>(drawing), null);
    }

    public void addDrawingNode(DLNode<Object> drawingNode, DLNode<Object> referenceNode) {
        ((DLList)indexedDrawings).addNode(referenceNode, drawingNode, true);

        final Drawing drawing = (Drawing)drawingNode.getObject();
		final DrawingAnchor anchor = drawing.getAnchor();
		if(anchor!=null) {
			List<Drawing> anchoredDrawingsList = anchoredDrawings.get(anchor);
			if(anchoredDrawingsList==null) {
				anchoredDrawingsList = new ArrayList<Drawing>();
				anchoredDrawings.put(anchor, anchoredDrawingsList);
			}
			anchoredDrawingsList.add(drawing);
		}
	}

    public void moveDrawing(int from, int to) {
        Drawing drawing = indexedDrawings.remove(from);
        indexedDrawings.add(to, drawing);
    }

	public void setDrawingAnchor(DrawingAnchor newAnchor, Drawing drawing) {

		// first removing the old anchor if any
		if(drawing.getAnchor()!=null) {
			final List<Drawing> anchoredDrawingList = anchoredDrawings.get(drawing.getAnchor());
			anchoredDrawingList.remove(drawing);
			if(anchoredDrawingList.isEmpty()) {
				anchoredDrawings.remove(drawing.getAnchor());
			}
 		}
		// adding our new drawingAnchor
		drawing.setDrawingAnchor(newAnchor);
		if(newAnchor!=null) {
		    List<Drawing> anchoredDrawingsList = anchoredDrawings.get(newAnchor);
			if(anchoredDrawingsList==null) {
				anchoredDrawingsList = new ArrayList<Drawing>();
				anchoredDrawings.put(newAnchor, anchoredDrawingsList);
			}
			anchoredDrawingsList.add(drawing);
		}
	}

	public List<Drawing> getIndexedDrawings() {
	    return indexedDrawings;
	}

	public List<Drawing> getAnchoredDrawings(DrawingAnchor drawingAnchor) {
		return anchoredDrawings.get(drawingAnchor);
	}

    public void deleteDrawing(int index, OdfOperationDoc opsDoc) {
		final Drawing drawing = indexedDrawings.remove(index);
		if(drawing.getAnchor()!=null) {
			final List<Drawing> anchoredDrawingList = anchoredDrawings.get(drawing.getAnchor());
			anchoredDrawingList.remove(drawing);
			if(anchoredDrawingList.isEmpty()) {
				anchoredDrawings.remove(drawing.getAnchor());
			}
		}
		if(drawing.getType()==DrawingType.CHART) {
		    final ChartContent chart = ((DrawObject)((DrawFrame)drawing.getShape()).getDrawing()).getChart();
	        if (chart!=null) {
	            deleteChartPart(opsDoc.getDocument().getPackage(), chart);
	        }
		}
	}

    public static void deleteChartPart(OdfPackage pkg, ChartContent chart) {
        final String internalPath = chart.getDocument().getDocumentPath();
        pkg.remove(internalPath + "content.xml");
        pkg.remove(internalPath + "meta.xml");
        pkg.remove(internalPath + "styles.xml");
        pkg.removeDocument(internalPath);
    }
}
